==> worlds_candybox2-0.0.0.tar.gz: worlds_candybox2-0.0.0/src/worlds/candybox2/docs/en_Candy Box 2.md <==
# Candy Box 2

## What is this game?
Candy Box 2 is a text based RPG that runs in all modern browsers. You can play the original game (without Archipelago
support) at [https://candybox2.github.io](https://candybox2.github.io)

## Where is the options page?
The [player options page for this game](../player-options) contains all the options you need to configure
and export a config file.

## What does randomization do to this game?
By default, items are shuffled. Quests and entrances may also, depending on your settings, be shuffled to different
locations.

## What items and locations get shuffled?
Anything that lands in your inventory and any single-shot action that gives you candies, lollipops or chocolates are
randomized. Additionally, the world map must progressively be unlocked.

## Which items can be in another player's world?
Any of the items which can be shuffled my end up in another player's world.

## What does another world's item look like in Candy Box 2?
- When purchasing an item from a merchant, the merchant will tell you exactly what you will be buying.
- When obtaining an item in a quest, the quest log updates to tell you what exactly will be sent.
- Other items are otherwise visually unchanged.

## When the player receives an item, what happens?
When the player receives an item, they will receive an Archipelago Update notification telling them
about the item that they have received.

## What is the goal of this game when randomized?
To win, you must open the locked candy box. This involves finding the castle tower, obtaining the P, L, A and Y
stones, as well as the Locked Candy Box, and inserting the stones in order to find the talking candy.

## How does DeathLink work with this game?
- You send a DeathLink when you die in a quest. Quitting a quest before you die will not send a DeathLink.
- When others send you a DeathLink, your HP will instantly drop to 0. Additionally, if you are in a quest, you will
  fail it instantly, and possibly lose anything you've found in that quest, depending on which quest you are in.

## What is EnergyLink?
EnergyLink is an energy storage supported by certain games that is shared across all worlds in a multiworld. In Candy
Box 2, if enabled in the player options, the Share House (the first house in the village) will be unlocked, and you will
be able to visit the Energy Room. There, you can convert candies and lollipops to and from energy.

Depositing candies and lollipops into the EnergyLink system comes with a 25% efficiency penalty. You can check how much
energy is in the EnergyLink system by visiting the Energy Room, where the total amount of energy available in the
EnergyLink system will be shown.

## How does gifting work with this game?
- Brewed potions can be sent as gifts to other games that support this feature.
- Gifts can be sent from the Post Office, in the first house of the village.
- When gifts are received, a notification appears to let you know that you can visit the Post Office and receive
  an item.

==> worlds_candybox2-1.20251208.1.tar.gz: worlds_candybox2-1.20251208.1/src/worlds/candybox2/docs/en_Candy Box 2.md <==
# Candy Box 2

## What is this game?
Candy Box 2 is a text based RPG that runs in all modern browsers. You can play the original game (without MultiworldGG
support) at [https://candybox2.github.io](https://candybox2.github.io)

## Where is the options page?
The [player options page for this game](../player-options) contains all the options you need to configure
and export a config file.

## What does randomization do to this game?
By default, items are shuffled. Quests and entrances may also, depending on your settings, be shuffled to different
locations.

## What items and locations get shuffled?
Anything that lands in your inventory and any single-shot action that gives you candies, lollipops or chocolates are
randomized. Additionally, the world map must progressively be unlocked.

## Which items can be in another player's world?
Any of the items which can be shuffled may end up in another player's world.

## What does another world's item look like in Candy Box 2?
- When purchasing an item from a merchant, the merchant will tell you exactly what you will be buying.
- When obtaining an item in a quest, the quest log updates to tell you what exactly will be sent.
- Other items are otherwise visually unchanged.

## When the player receives an item, what happens?
When the player receives an item, they will receive an Archipelago Update notification telling them
about the item that they have received.

## What is the goal of this game when randomized?
To win, you must open the locked candy box. This involves finding the castle tower, obtaining the P, L, A and Y
stones, as well as the Locked Candy Box, and inserting the stones in order to find the talking candy.

## How does DeathLink work with this game?
- You send a DeathLink when you die in a quest. Quitting a quest before you die will not send a DeathLink.
- When others send you a DeathLink, your HP will instantly drop to 0. Additionally, if you are in a quest, you will
  fail it instantly, and possibly lose anything you've found in that quest, depending on which quest you are in.

## What is EnergyLink?
EnergyLink is an energy storage supported by certain games that is shared across all worlds in a multiworld. In Candy
Box 2, if enabled in the player options, the Share House (the first house in the village) will be unlocked, and you will
be able to visit the Energy Room. There, you can convert candies and lollipops to and from energy.

Depositing candies and lollipops into the EnergyLink system comes with a 25% efficiency penalty. You can check how much
energy is in the EnergyLink system by visiting the Energy Room, where the total amount of energy available in the
EnergyLink system will be shown.

## How does gifting work with this game?
- Brewed potions can be sent as gifts to other games that support this feature.
- Gifts can be sent from the Post Office, in the first house of the village.
- When gifts are received, a notification appears to let you know that you can visit the Post Office and receive
  an item.
